@@ -1,5 +1,5 @@
 /*  smplayer, GUI front-end for mplayer.
-    Copyright (C) 2006-2015 Ricardo Villalba <rvm@users.sourceforge.net>
+    Copyright (C) 2006-2016 Ricardo Villalba <rvm@users.sourceforge.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -43,6 +43,8 @@
 
 #define RENAME_PICTURES 0
 
+#define N_OUTPUT_FRAMES 1
+
 // MPlayer2 doesn't support png outdir
 /* #define VP_USE_PNG_OUTDIR */
 
@@ -66,8 +68,9 @@ VideoPreview::VideoPreview(QString mplayer_path, QWidget * parent) : QWidget(par
 	output_dir = "smplayer_preview";
 	full_output_dir = QDir::tempPath() +"/"+ output_dir;
 
-	progress = new QProgressDialog(this);
+	progress = new QProgressDialog(parent != 0 ? parent : this);
 	progress->setMinimumDuration(0);
+	progress->reset(); // Prevent the dialog to be shown on initialization (Qt 5.5)
 	connect( progress, SIGNAL(canceled()), this, SLOT(cancelPressed()) );
 
 	w_contents = new QWidget(this);
@@ -170,10 +173,7 @@ void VideoPreview::clearThumbnails() {
 }
 
 QString VideoPreview::framePicture() {
-	if (prop.extract_format == PNG)
-		return "00000005.png";
-	else
-		return "00000005.jpg";
+	return QString("0000000%1.%2").arg(N_OUTPUT_FRAMES == 1 ? 1 : N_OUTPUT_FRAMES-1).arg(prop.extract_format == PNG ? "png" : "jpg");
 }
 
 bool VideoPreview::createThumbnails() {
@@ -278,23 +278,26 @@ bool VideoPreview::runPlayer(int seek, double aspect_ratio) {
 		#ifdef MPV_SUPPORT
 		// MPV
 		args << "--no-config" << "--no-audio" << "--no-cache";
-		args << "--frames=6" << "--framedrop=no" << "--start=" + QString::number(seek);
+		args << "--frames=" + QString::number(N_OUTPUT_FRAMES);
+		args << "--framedrop=no" << "--start=" + QString::number(seek);
 		if (aspect_ratio != 0) {
 			args << "--video-aspect=" + QString::number(aspect_ratio);
 		}
 		if (!prop.dvd_device.isEmpty()) args << "--dvd-device=" + prop.dvd_device;
 		QString format = (prop.extract_format == PNG) ? "png:png-compression=0" : "jpg";
 		args << QString("--vo=image=format=%1:outdir=\"%2\"").arg(format).arg(full_output_dir);
-		
+
+		/*
 		#ifdef Q_OS_WIN
-		args << "--use-text-osd=no";
+		args << "--use-text-osd=no"; // option removed in mpv 0.12
 		#endif
+		*/
 		#endif // MPV_SUPPORT
 	}
 	else {
 		#ifdef MPLAYER_SUPPORT
 		// MPlayer
-		args << "-nosound" << "-nocache";
+		args << "-nosound" << "-nocache" << "-noframedrop";
 
 		if (prop.extract_format == PNG) {
 			args << "-vo"
@@ -308,7 +311,7 @@ bool VideoPreview::runPlayer(int seek, double aspect_ratio) {
 			<< "jpeg:outdir=\""+full_output_dir+"\"";
 		}
 
-		args << "-frames" << "6" << "-ss" << QString::number(seek);
+		args << "-frames" << QString::number(N_OUTPUT_FRAMES) << "-ss" << QString::number(seek);
 
 		if (aspect_ratio != 0) {
 			args << "-aspect" << QString::number(aspect_ratio) << "-zoom";
@@ -402,7 +405,8 @@ bool VideoPreview::addPicture(const QString & filename, int num, int time) {
 
 void VideoPreview::displayVideoInfo(const VideoInfo & i) {
 	// Display info about the video
-	QTime t = QTime().addSecs(i.length);
+	QTime t(0,0);
+	t = t.addSecs(i.length);
 
 	QString aspect = QString::number(i.aspect);
 	if (fabs(1.77 - i.aspect) < 0.1) aspect = "16:9";
